/*
** Module   : JobType.java
** Abstract : enum defining the possible job types.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20140206 First version.
*/

package com.goldencode.p2j.main;

/**
 * Definition of possible job types:
 * <ul>
 * <li>{@link #PROCESS} - a P2J process.</li>
 * <li>{@link #CLASS} - a Java class implementing {@link Runnable}.</li>
 * <li>{@link #METHOD} - a method name qualified with the full class name. Must have no 
 *     parameters.</li>
 * </ul>
 */
public enum JobType
{
   PROCESS ("PROCESS"),
   CLASS   ("CLASS"),
   METHOD  ("METHOD");
   
   /** String representation of this job type. */
   private final String type;
   
   /**
    * Initialize a new job type.
    * 
    * @param    type
    *           The job type.
    */
   JobType(String type)
   {
      this.type = type;
   }

   /**
    * Resolve the job type from the given string.
    * 
    * @param    type
    *           The job type.
    *           
    * @return   One of the {@link JobType} values or {@code null} if it can not be resolved.
    */
   public static JobType resolveJobType(String type)
   {
      for (JobType jobType: JobType.values())
      {
         if (jobType.type.equalsIgnoreCase(type))
         {
            return jobType;
         }
      }

      return null;
   }
}